@@ -1,20 +1,7 @@
 /*
- * <one line to give the library's name and an idea of what it does.>
- * Copyright (C) 2015  David Edmundson <david@davidedmundson.co.uk>
+ * SPDX-FileCopyrightText: 2015 David Edmundson <david@davidedmundson.co.uk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
@@ -22,8 +9,8 @@
 #define STATISTICSPROVIDER_H
 
 #include <QObject>
-#include <QQmlParserStatus>
 #include <QPointF>
+#include <QQmlParserStatus>
 
 struct HistoryReply {
 public:
@@ -94,7 +81,7 @@ public Q_SLOTS:
 private:
     QString m_device;
     HistoryType m_type;
-    uint m_duration; //in seconds
+    uint m_duration; // in seconds
 
     QList<HistoryReply> m_values;
     bool m_isComplete = false;
